@@ -1,13 +1,16 @@
 #' @export
 print.kableExtra <- function(x, ...) {
-  cat(as.character(x))
   html_header <- htmltools::tags$head(
     rmarkdown::html_dependency_jquery(),
     rmarkdown::html_dependency_bootstrap(theme = "simplex"),
     html_dependency_kePrint()
   )
   html_table <- htmltools::HTML(as.character(x))
-  htmltools::html_print(htmltools::tagList(html_header, html_table))
+  html_result <- htmltools::tagList(html_header, html_table)
+  if (interactive() & rstudioapi::isAvailable()) {
+    htmltools::html_print(html_result, viewer = rstudioapi::viewer)
+  }
+  print(html_result)
 }
 
 html_dependency_kePrint <- function() {
