@@ -12,6 +12,8 @@
     usepackage_latex("pdflscape")
     usepackage_latex("tabu")
     usepackage_latex("threeparttable")
+    usepackage_latex("threeparttablex")
     usepackage_latex("ulem", "normalem")
+    usepackage_latex("makecell")
   }
 }
